==> openshift-model-6.3.1-sources.jar: io/fabric8/openshift/api/model/BuildListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildListFluent<A extends BuildListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Build item);
  public A setToItems(Integer index,Build item);
  public A addToItems(io.fabric8.openshift.api.model.Build... items);
  public A addAllToItems(Collection<Build> items);
  public A removeFromItems(io.fabric8.openshift.api.model.Build... items);
  public A removeAllFromItems(Collection<Build> items);
  public A removeMatchingFromItems(Predicate<BuildBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Build> getItems();
  public List<Build> buildItems();
  public Build buildItem(Integer index);
  public Build buildFirstItem();
  public Build buildLastItem();
  public Build buildMatchingItem(Predicate<BuildBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<BuildBuilder> predicate);
  public A withItems(List<Build> items);
  public A withItems(io.fabric8.openshift.api.model.Build... items);
  public Boolean hasItems();
  public BuildListFluent.ItemsNested<A> addNewItem();
  public BuildListFluent.ItemsNested<A> addNewItemLike(Build item);
  public BuildListFluent.ItemsNested<A> setNewItemLike(Integer index,Build item);
  public BuildListFluent.ItemsNested<A> editItem(Integer index);
  public BuildListFluent.ItemsNested<A> editFirstItem();
  public BuildListFluent.ItemsNested<A> editLastItem();
  public BuildListFluent.ItemsNested<A> editMatchingItem(Predicate<BuildBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,BuildFluent<BuildListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/BuildListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildListFluent<A extends BuildListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Build item);
  public A setToItems(int index,Build item);
  public A addToItems(io.fabric8.openshift.api.model.Build... items);
  public A addAllToItems(Collection<Build> items);
  public A removeFromItems(io.fabric8.openshift.api.model.Build... items);
  public A removeAllFromItems(Collection<Build> items);
  public A removeMatchingFromItems(Predicate<BuildBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Build> getItems();
  public List<Build> buildItems();
  public Build buildItem(int index);
  public Build buildFirstItem();
  public Build buildLastItem();
  public Build buildMatchingItem(Predicate<BuildBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<BuildBuilder> predicate);
  public A withItems(List<Build> items);
  public A withItems(io.fabric8.openshift.api.model.Build... items);
  public Boolean hasItems();
  public BuildListFluent.ItemsNested<A> addNewItem();
  public BuildListFluent.ItemsNested<A> addNewItemLike(Build item);
  public BuildListFluent.ItemsNested<A> setNewItemLike(int index,Build item);
  public BuildListFluent.ItemsNested<A> editItem(int index);
  public BuildListFluent.ItemsNested<A> editFirstItem();
  public BuildListFluent.ItemsNested<A> editLastItem();
  public BuildListFluent.ItemsNested<A> editMatchingItem(Predicate<BuildBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,BuildFluent<BuildListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
